@@ -20,21 +20,9 @@ The R::NDArray::FloatComplex class in L<SPVM> has methods to do someting.
 
 
 
-=head1 Inheritance
-
-
-
-=head1 Interfaces
-
-
-
-=head1 Enumerations
-
-
-
-=head1 Fields
-
+=head1 Super Class
 
+L<R::NDArray|SPVM::R::NDArray>
 
 =head1 Class Methods
 
@@ -44,15 +32,6 @@ The R::NDArray::FloatComplex class in L<SPVM> has methods to do someting.
 
 
 
-
-=head1 Repository
-
-
-
-=head1 Author
-
-Yuki Kimoto C<kimoto.yuki@gmail.com>
-
 =head1 Copyright & License
 
 Copyright (c) 2024 Yuki Kimoto
